@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2005-2010 Licq developers
+ * Copyright (C) 2005-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,15 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __MSN_CONSTANTS_H
-#define __MSN_CONSTANTS_H
+#ifndef LICQMSN_MSNCONSTANTS_H
+#define LICQMSN_MSNCONSTANTS_H
+
+namespace LicqMsn
+{
 
 const char DP_EUF_GUID[] = "{A4268EEC-FEC5-49E5-95C3-F126696BDBF6}";
 
+} // namespace LicqMsn
+
 #endif
 
