@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2000-2010 Licq developers
+ * Copyright (C) 2000-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ private:
   virtual void dragEnterEvent(QDragEnterEvent* dee);
   virtual void dropEvent(QDropEvent* de);
   QString s1, s2;
-  unsigned long m_nEventType;
+  unsigned myEventType;
   InfoField* edtUser;
   QPushButton* btnOk;
   QPushButton* btnCancel;
