@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2010 Licq developers
+ * Copyright (C) 1999-2011 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,12 +24,14 @@
 
 #include <licq/logging/pluginlogsink.h>
 
+class QAction;
+class QMenu;
 class QShowEvent;
 class QSocketNotifier;
 
 namespace LicqQtGui
 {
-class MLEdit;
+class MLView;
 
 class LogWindow : public QDialog
 {
@@ -39,14 +41,15 @@ public:
   LogWindow(QWidget* parent = 0);
   ~LogWindow();
 
-  Licq::PluginLogSink::Ptr pluginLogSink() { return myLogSink; }
-
 private:
-  MLEdit* outputBox;
+  MLView* outputBox;
   QSocketNotifier* sn;
   Licq::PluginLogSink::Ptr myLogSink;
+  QMenu* myDebugMenu;
 
 private slots:
+  void aboutToShowDebugMenu();
+  void changeDebug(QAction* action);
   void log(int fd);
   void save();
 };
