@@ -33,7 +33,6 @@ class UserId;
 
 namespace LicqQtGui
 {
-class RegisterUserDlg;
 
 /**
  * Dialog for managing accounts
@@ -68,14 +67,6 @@ private slots:
    */
   void registerOwner(unsigned long protocolId);
 
-  /**
-   * Registration dialog has finished
-   *
-   * @param success True if a new account was created
-   * @param userId Id of new account
-   */
-  void registerDone(bool success, const Licq::UserId& userId);
-
   /**
    * Edit currently selected account
    */
@@ -132,8 +123,6 @@ private:
    */
   virtual ~OwnerManagerDlg();
 
-  RegisterUserDlg* registerUserDlg;
-
   QTreeWidget* myOwnerView;
   QPushButton* myAddButton;
   QPushButton* myRegisterButton;
