@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2007-2010 Licq developers
+ * Copyright (C) 2007-2010, 2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ GroupComboBox::GroupComboBox(bool groupPos, QWidget* parent)
   BOOST_FOREACH(const Licq::Group* group, **groupList)
   {
     Licq::GroupReadGuard pGroup(group);
-    QString text(pGroup->name().c_str());
+    QString text = QString::fromLocal8Bit(pGroup->name().c_str());
     if (groupPos)
       text.prepend(tr("After "));
     addItem(text, pGroup->id());
