@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010,2012 Licq Developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@ using ::testing::StrictMock;
 
 using namespace LicqDaemon;
 
+namespace LicqTest {
+
 class LogFixture : public ::testing::TestWithParam<Licq::Log::Level>
 {
 public:
@@ -219,13 +221,10 @@ TEST(Log, streamCopyConstructor)
   }
 }
 
-namespace
-{
 struct Custom
 {
   int myValue;
 };
-}
 
 static std::ostream& operator<<(std::ostream& os, const Custom& c)
 {
@@ -245,3 +244,5 @@ TEST(Log, streamCustomDataType)
   Custom c; c.myValue = 256;
   log.log(Log::Error) << c << " = " << std::showbase << std::hex << c;
 }
+
+} // namespace LicqTest
