@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010,2012 Licq Developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 
 #include "gmock/gmock.h"
 
+namespace LicqTest {
+
 class MockLogSink : public Licq::LogSink
 {
 public:
@@ -32,4 +34,6 @@ public:
   MOCK_METHOD1(log, void(Message::Ptr message));
 };
 
+} // namespace LicqTest
+
 #endif
