@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010 Licq developers
+ * Copyright (C) 2010-2011 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,11 @@ Licq::ThreadLog Licq::gLog;
 
 Licq::Log* Licq::ThreadLog::getLog()
 {
-  using LicqDaemon::LogService;
+  using LicqDaemon::gLogService;
 
-  Log* log = LogService::instance().getThreadLog();
+  Log* log = gLogService.getThreadLog();
   if (log != NULL)
     return log;
 
-  return &LogService::instance().getLog();
+  return &gLogService.getLog();
 }
