@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2010-2011 Licq developers
+ * Copyright (C) 2010-2012 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,11 @@ unsigned long Licq::Packet::s_nRealIp = 0;
 unsigned short Licq::Packet::s_nLocalPort = 0;
 
 Licq::Packet::Packet()
-  : buffer(NULL)
 {
   // Empty
 }
 
 Licq::Packet::~Packet()
 {
-  delete buffer;
+  // Empty
 }
