@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1998-2012 Licq developers <licq-dev@googlegroups.com>
+ * Copyright (C) 1998-2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,10 @@ SSL_CTX *gSSL_CTX_NONICQ;
 extern "C" {
 #include <socks.h>
 }
+#define socket_send Rsend
+#undef send
+#else
+#define socket_send send
 #endif // SOCKS5
 
 #ifdef SOCKS5_OPTLEN
@@ -65,13 +69,12 @@ extern "C" {
 
 #include "gettext.h"
 
-
-using namespace std;
 using Licq::Buffer;
 using Licq::INetSocket;
 using Licq::TCPSocket;
 using Licq::UDPSocket;
 using Licq::UserId;
+using std::string;
 
 char* Licq::ip_ntoa(unsigned long in, char *buf)
 {
@@ -434,7 +437,7 @@ bool INetSocket::StartServer(unsigned int _nPort)
   }
 #endif
 
-  if (bind(myDescriptor, (struct sockaddr*)&myLocalAddr, addrlen) == -1)
+  if (::bind(myDescriptor, (struct sockaddr*)&myLocalAddr, addrlen) == -1)
   {
     myErrorType = ErrorErrno;
     ::close(myDescriptor);
@@ -478,7 +481,7 @@ bool INetSocket::send(Buffer& buf)
   char* dataPos = buf.getDataStart();
   while (bytesLeft > 0)
   {
-    ssize_t bytesSent = ::send(myDescriptor, dataPos, bytesLeft, 0);
+    ssize_t bytesSent = ::socket_send(myDescriptor, dataPos, bytesLeft, 0);
     if (bytesSent < 0)
     {
       if (errno == EINTR)
@@ -587,7 +590,11 @@ bool TCPSocket::RecvConnection(TCPSocket &newSocket)
   return success;
 }
 
+#ifdef USE_OPENSSL
 #define m_pSSL ((SSL *) m_p_SSL)
+#else
+#define m_pSSL m_p_SSL
+#endif
 
 /*-----TCPSocket::TransferConnectionFrom---------------------------------------
  * Transfers a connection from the given socket to the current one and closes
@@ -655,6 +662,8 @@ bool TCPSocket::send(Buffer& buf)
   DumpPacket(&buf, false);
 
   return true;
+#else
+  return false;
 #endif
 }
 
@@ -711,6 +720,8 @@ bool TCPSocket::receive(Buffer& buf, size_t maxlength, bool dump)
     DumpPacket(&buf, true);
 
   return (true);
+#else
+  return false;
 #endif
 }
 
@@ -731,7 +742,7 @@ bool TCPSocket::SSL_Pending()
 bool TCPSocket::SecureConnect()
 {
   pthread_mutex_init(&mutex_ssl, NULL);
-  if (myUserId.protocolId() == LICQ_PPID)
+  if (myUserId.protocolId() == ICQ_PPID)
     m_p_SSL = SSL_new(gSSL_CTX);
   else
     m_p_SSL = SSL_new(gSSL_CTX_NONICQ);
@@ -767,7 +778,7 @@ bool TCPSocket::SecureListen()
 {
   pthread_mutex_init(&mutex_ssl, NULL);
 
-  if (myUserId.protocolId() == LICQ_PPID)
+  if (myUserId.protocolId() == ICQ_PPID)
     m_p_SSL = SSL_new(gSSL_CTX);
   else
     m_p_SSL = SSL_new(gSSL_CTX_NONICQ);
