@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 2000-2010 Licq developers
+ * Copyright (C) 2000-2010, 2013 Licq developers <licq-dev@googlegroups.com>
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 
 #include <licq/daemon.h>
 
-using namespace std;
 using Licq::gDaemon;
 
 class ReadWriteMutex::Private
@@ -101,7 +100,7 @@ void ReadWriteMutex::Private::debugWait(bool writing)
     printUsers(stderr, writing);
 
     // Also save it in <basedir>/licq.debug_rw_mutex
-    string filename = gDaemon.baseDir() + "licq.debug_rw_mutex";
+    std::string filename = gDaemon.baseDir() + "licq.debug_rw_mutex";
     FILE* file = ::fopen(filename.c_str(), "w");
     if (file != NULL)
     {
